@@ -42,6 +42,7 @@ from hoss_agent import VERSION
 from hoss_agent.conf import constants
 from hoss_agent.contrib.async_worker import AsyncWorker
 from hoss_agent.utils import compat, json_encoder
+from hoss_agent.utils.bytes_key_to_string import bytes_key_to_string
 from hoss_agent.utils.compat import BytesIO
 from hoss_agent.utils.logging import get_logger
 from hoss_agent.utils.runtime_env import get_runtime_env
@@ -178,37 +179,53 @@ class Transport(ThreadManager):
     # helper to decode body payload from BytesIO object into string
     # if fail, payload is removed
     def _decode_or_truncate_body_payload(self, data):
-        if isinstance(data['request']['body'], bytes):
-            data['request']['body'] = data['request']['body'].decode()
-        elif isinstance(data['request']['body'], BytesIO):
-            data['request']['body'] = data['request']['body'].getvalue().decode()
-        else:
-            logger.debug('Cannot decode request body into string: %s. Removing it')
-            data['request']['body'] = None
-
-        if 'response' in data:
-            if isinstance(data['response']['body'], bytes):
-                data['response']['body'] = data['response']['body'].decode()
-            elif isinstance(data['response']['body'], BytesIO):
-                data['response']['body'] = data['response']['body'].getvalue().decode()
+        try:
+            if isinstance(data['request']['body'], bytes):
+                data['request']['body'] = data['request']['body'].decode()
+            elif isinstance(data['request']['body'], BytesIO):
+                data['request']['body'] = data['request']['body'].getvalue().decode()
             else:
-                logger.debug('Cannot decode response body into string: %s. Removing it')
-                data['response']['body'] = None
+                logger.debug('Cannot decode request body into string: %s. Removing it')
+                data['request']['body'] = None
+        except Exception as ex:
+            logger.debug('Cannot decode request body into string: %s. Removing it', ex)
+            data['request']['body'] = None
+        try:
+            if 'response' in data:
+                if isinstance(data['response']['body'], bytes):
+                    data['response']['body'] = data['response']['body'].decode()
+                elif isinstance(data['response']['body'], BytesIO):
+                    data['response']['body'] = data['response']['body'].getvalue().decode()
+                else:
+                    logger.debug('Cannot decode response body into string: %s. Removing it')
+                    data['response']['body'] = None
+        except Exception as ex:
+            logger.debug('Cannot decode response body into string: %s. Removing it', ex)
+            data['response']['body'] = None
 
     # helper to base64 encode request & response payload
     # if fail, payload is removed
     def _encode_body_payload(self, data):
-        # encode sanitized payload
-        if isinstance(data['request']['body'], bytes):
-            data['request']['body'] = base64.b64encode(data['request']['body']).decode()
-        else:
-            data['request']['body'] = base64.b64encode(data['request']['body'].encode('utf-8')).decode()
-
-        if 'response' in data:
-            if isinstance(data['response']['body'], bytes):
-                data['response']['body'] = base64.b64encode(data['response']['body']).decode()
+        try:
+            # encode sanitized payload
+            if isinstance(data['request']['body'], bytes):
+                data['request']['body'] = base64.b64encode(data['request']['body']).decode()
             else:
-                data['response']['body'] = base64.b64encode(data['response']['body'].encode('utf-8')).decode()
+                data['request']['body'] = base64.b64encode(data['request']['body'].encode('utf-8')).decode()
+        except Exception as ex:
+            logger.debug('Cannot b64encode request body: %s. Replacing it with empty string', ex)
+            data['request']['body'] = ""
+
+        try:
+            if 'response' in data:
+                if isinstance(data['response']['body'], bytes):
+                    data['response']['body'] = base64.b64encode(data['response']['body']).decode()
+                else:
+                    data['response']['body'] = base64.b64encode(data['response']['body'].encode('utf-8')).decode()
+        except Exception as ex:
+            logger.debug('Cannot b64encode response body: %s. replaceing it with empty string', ex)
+            data['response']['body'] = ""
+
 
     def _process_event(self, event_type, data):
         if event_type is None or data is None:
@@ -221,7 +238,7 @@ class Transport(ThreadManager):
             api_config = self.client.config.api_host_mapping.get(host)
 
         self._decode_or_truncate_body_payload(data)
-
+        data = bytes_key_to_string(data)
         # Run the data through processors
         for processor in self._processors:
             if not hasattr(processor, "event_types") or event_type in processor.event_types:
